@@ -25,6 +25,7 @@ I3S_INSTANCE_MODULES = [
     "ethernet",
     "memory",
     "path_exists",
+    "read_file",
     "run_watch",
     "tztime",
     "volume",
@@ -244,6 +245,12 @@ RETIRED_MODULES = {
         "new": ["weather_owm"],
         "msg": "Module {old} is no longer available due to retired Yahoo Weather APIs and new Oath requirements. You can try a different module {new}.",
     },
+    "xkb_layouts": {
+        "new": ["xkb_input"],
+        "msg": "Module {old} has been replaced with a module {new} to support sway too.",
+    },
 }
 
 MARKUP_LANGUAGES = ["pango", "none"]
+
+ON_ERROR_VALUES = ["hide", "show"]
