@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Display date and time.
 
@@ -38,6 +37,9 @@ Configuration parameters:
         a list.  The one used can be changed by button click.
         *(default ['[{name_unclear} ]%c', '[{name_unclear} ]%x %X',
         '[{name_unclear} ]%a %H:%M', '[{name_unclear} ]{icon}'])*
+    locale: Override the system locale. Examples:
+        when set to 'fr_FR' %a on Tuesday is 'mar.'.
+        (default None)
     round_to_nearest_block: defines how a block icon is chosen. Examples:
         when set to True,  '13:14' is '🕐', '13:16' is '🕜' and '13:31' is '🕜';
         when set to False, '13:14' is '🕐', '13:16' is '🕐' and '13:31' is '🕜'.
@@ -53,11 +55,10 @@ Format placeholders:
         but is empty if only one timezone is provided
 
 Requires:
-    pytz: python library
-    tzlocal: python library
-
-i3status.conf example:
+    pytz: cross platform time zone library for python
+    tzlocal: tzinfo object for the local timezone
 
+Examples:
 ```
 # cycling through London, Warsaw, Tokyo
 clock {
@@ -66,14 +67,12 @@ clock {
     format_time = "{name} %H:%M"
 }
 
-
 # Show the time and date in New York
 clock {
    format = "Big Apple {America/New_York}"
    format_time = "%Y-%m-%d %H:%M:%S"
 }
 
-
 # wall clocks
 clock {
     format = "{Asia/Calcutta} {Africa/Nairobi} {Asia/Bangkok}"
@@ -90,8 +89,8 @@ SAMPLE OUTPUT
 london
 {'full_text': 'Thursday Feb 23 1:42 AM London'}
 """
-from __future__ import division
 
+import locale
 import re
 from datetime import datetime
 from time import time
@@ -99,12 +98,13 @@ from time import time
 import pytz
 import tzlocal
 
-CLOCK_BLOCKS = u'🕛🕧🕐🕜🕑🕝🕒🕞🕓🕟🕔🕠🕕🕡🕖🕢🕗🕣🕘🕤🕙🕥🕚🕦'
+CLOCK_BLOCKS = "🕛🕧🕐🕜🕑🕝🕒🕞🕓🕟🕔🕠🕕🕡🕖🕢🕗🕣🕘🕤🕙🕥🕚🕦"
 
 
 class Py3status:
     """
     """
+
     # available configuration parameters
     block_hours = 12
     blocks = CLOCK_BLOCKS
@@ -114,14 +114,18 @@ class Py3status:
     cycle = 0
     format = "{Local}"
     format_time = [
-        '[{name_unclear} ]%c',
-        '[{name_unclear} ]%x %X',
-        '[{name_unclear} ]%a %H:%M',
-        '[{name_unclear} ]{icon}',
+        "[{name_unclear} ]%c",
+        "[{name_unclear} ]%x %X",
+        "[{name_unclear} ]%a %H:%M",
+        "[{name_unclear} ]{icon}",
     ]
+    locale = None
     round_to_nearest_block = True
 
     def post_config_hook(self):
+        if self.locale is not None:
+            locale.setlocale(locale.LC_TIME, self.locale)
+
         # Multiple clocks are possible that can be cycled through
         if not isinstance(self.format, list):
             self.format = [self.format]
@@ -129,14 +133,11 @@ class Py3status:
         if len(self.format) == 1:
             self.cycle = 0
         # find any declared timezones eg {Europe/London}
-        self._items = {}
-        fmts = set()
+        self._fmts = set()
         for fmt in self.format:
-            fmts.update(self.py3.get_placeholders_list(fmt))
-        for fmt in fmts:
-            self._items[fmt] = self._get_timezone(fmt)
+            self._fmts.update(self.py3.get_placeholders_list(fmt))
 
-        self.multiple_tz = len(self._items) > 1
+        self.multiple_tz = len(self._fmts) > 1
 
         if not isinstance(self.format_time, list):
             self.format_time = [self.format_time]
@@ -145,24 +146,24 @@ class Py3status:
         # display fresh
         self.time_deltas = []
         for format in self.format_time:
-            format_time = re.sub(r'\{([^}]*)\}', '', format)
-            format_time = format_time.replace('%%', '')
-            if '%f' in format_time:
+            format_time = re.sub(r"\{([^}]*)\}", "", format)
+            format_time = format_time.replace("%%", "")
+            if "%f" in format_time:
                 # microseconds
                 time_delta = 0
-            elif '%S' in format_time:
+            elif "%S" in format_time:
                 # seconds
                 time_delta = 1
-            elif '%s' in format_time:
+            elif "%s" in format_time:
                 # seconds since unix epoch start
                 time_delta = 1
-            elif '%T' in format_time:
+            elif "%T" in format_time:
                 # seconds included in "%H:%M:%S"
                 time_delta = 1
-            elif '%c' in format_time:
+            elif "%c" in format_time:
                 # Locale’s appropriate date and time representation
                 time_delta = 1
-            elif '%X' in format_time:
+            elif "%X" in format_time:
                 # Locale’s appropriate time representation
                 time_delta = 1
             else:
@@ -170,13 +171,13 @@ class Py3status:
             self.time_deltas.append(time_delta)
 
         # If we have saved details we use them.
-        saved_format = self.py3.storage_get('time_format')
+        saved_format = self.py3.storage_get("time_format")
         if saved_format in self.format_time:
             self.active_time_format = self.format_time.index(saved_format)
         else:
             self.active_time_format = 0
 
-        saved_timezone = self.py3.storage_get('timezone')
+        saved_timezone = self.py3.storage_get("timezone")
         if saved_timezone in self.format:
             self.active = self.format.index(saved_timezone)
         else:
@@ -185,36 +186,16 @@ class Py3status:
         # reset the cycle time
         self._cycle_time = time() + self.cycle
 
-        # set our _fmt_strftime function depending on python version
-        if self.py3.is_python_2():
-            self._fmt_strftime = self._fmt_strftime_py2
-        else:
-            self._fmt_strftime = self._fmt_strftime_py3
-
-    @staticmethod
-    def _fmt_strftime_py2(fmt, t):
-        """
-        strftime for python 2
-        """
-        return t.strftime(fmt.encode('utf-8'))
-
-    @staticmethod
-    def _fmt_strftime_py3(fmt, t):
-        """
-        strftime for python 3
-        """
-        return t.strftime(fmt)
-
     def _get_timezone(self, tz):
         """
         Find and return the time zone if possible
         """
         # special Local timezone
-        if tz == 'Local':
+        if tz == "Local":
             try:
                 return tzlocal.get_localzone()
             except pytz.UnknownTimeZoneError:
-                return '?'
+                return "?"
 
         # we can use a country code to get tz
         # FIXME this is broken for multi-timezone countries eg US
@@ -223,14 +204,14 @@ class Py3status:
             try:
                 zones = pytz.country_timezones(tz)
             except KeyError:
-                return '?'
+                return "?"
             tz = zones[0]
 
         # get the timezone
         try:
             zone = pytz.timezone(tz)
         except pytz.UnknownTimeZoneError:
-            return '?'
+            return "?"
         return zone
 
     def _change_active(self, diff):
@@ -239,22 +220,22 @@ class Py3status:
         self._cycle_time = time() + self.cycle
         # save the active format
         timezone = self.format[self.active]
-        self.py3.storage_set('timezone', timezone)
+        self.py3.storage_set("timezone", timezone)
 
     def on_click(self, event):
         """
         Switch the displayed module or pass the event on to the active module
         """
-        if event['button'] == self.button_reset:
+        if event["button"] == self.button_reset:
             self._change_active(0)
-        elif event['button'] == self.button_change_time_format:
+        elif event["button"] == self.button_change_time_format:
             self.active_time_format += 1
             if self.active_time_format >= len(self.format_time):
                 self.active_time_format = 0
             # save the active format_time
             time_format = self.format_time[self.active_time_format]
-            self.py3.storage_set('time_format', time_format)
-        elif event['button'] == self.button_change_format:
+            self.py3.storage_set("time_format", time_format)
+        elif event["button"] == self.button_change_format:
             self._change_active(1)
 
     def clock(self):
@@ -266,16 +247,17 @@ class Py3status:
 
         # update our times
         times = {}
-        for name, zone in self._items.items():
-            if zone == '?':
-                times[name] = '?'
+        for name in self._fmts:
+            zone = self._get_timezone(name)
+            if zone == "?":
+                times[name] = "?"
             else:
                 t = datetime.now(zone)
                 format_time = self.format_time[self.active_time_format]
                 icon = None
-                if self.py3.format_contains(format_time, 'icon'):
+                if self.py3.format_contains(format_time, "icon"):
                     # calculate the decimal hour
-                    h = t.hour + t.minute / 60.
+                    h = t.hour + t.minute / 60.0
                     if self.round_to_nearest_block:
                         h += (self.block_hours / len(self.blocks)) / 2
                     # make 12 hourly etc
@@ -284,14 +266,14 @@ class Py3status:
                     icon = self.blocks[idx]
 
                 timezone = zone.zone
-                tzname = timezone.split('/')[-1].replace('_', ' ')
+                tzname = timezone.split("/")[-1].replace("_", " ")
 
                 if self.multiple_tz:
                     name_unclear = tzname
                     timezone_unclear = timezone
                 else:
-                    name_unclear = ''
-                    timezone_unclear = ''
+                    name_unclear = ""
+                    timezone_unclear = ""
 
                 format_time = self.py3.safe_format(
                     format_time,
@@ -301,19 +283,18 @@ class Py3status:
                         name_unclear=name_unclear,
                         timezone=timezone,
                         timezone_unclear=timezone_unclear,
-                    ))
+                    ),
+                )
 
                 if self.py3.is_composite(format_time):
                     for item in format_time:
-                        item['full_text'] = self._fmt_strftime(item['full_text'], t)
+                        item["full_text"] = t.strftime(item["full_text"])
                 else:
-                    format_time = self._fmt_strftime(format_time, t)
+                    format_time = t.strftime(format_time)
                 times[name] = format_time
 
         # work out when we need to update
-        timeout = self.py3.time_in(
-            sync_to=self.time_deltas[self.active_time_format]
-        )
+        timeout = self.py3.time_in(sync_to=self.time_deltas[self.active_time_format])
 
         # if cycling we need to make sure we update when they are needed
         if self.cycle:
@@ -321,8 +302,8 @@ class Py3status:
             timeout = min(timeout, cycle_timeout)
 
         return {
-            'full_text': self.py3.safe_format(self.format[self.active], times),
-            'cached_until': timeout
+            "full_text": self.py3.safe_format(self.format[self.active], times),
+            "cached_until": timeout,
         }
 
 
@@ -331,4 +312,5 @@ if __name__ == "__main__":
     Run module in test mode.
     """
     from py3status.module_test import module_test
+
     module_test(Py3status)
