@@ -1,15 +1,15 @@
-# -*- coding: utf-8 -*-
 """
 Display output of a given script.
 
-Display output of any executable script set by `script_path`.
-Only the first two lines of output will be used. The first line is used
-as the displayed text. If the output has two or more lines, the second
-line is set as the text color (and should hence be a valid hex color
-code such as #FF0000 for red).
+Display output of any executable script set by `script_path`. Only the first
+two lines of output will be used. The first line is used as the displayed
+text. If the output has two or more lines, the second line is set as the text
+color (and should hence be a valid hex color code such as #FF0000 for red).
 The script should not have any parameters, but it could work.
 
 Configuration parameters:
+    button_show_notification: button to show notification with full output
+        (default None)
     cache_timeout: how often we refresh this module in seconds
         (default 15)
     format: see placeholders below (default '{output}')
@@ -21,10 +21,10 @@ Configuration parameters:
         (default False)
 
 Format placeholders:
+    {lines} number of lines in the output
     {output} output of script given by "script_path"
 
-i3status.conf example:
-
+Examples:
 ```
 external_script {
     format = "my name is {output}"
@@ -42,15 +42,18 @@ example
 """
 
 import re
-STRING_ERROR = 'missing script_path'
+
+STRING_ERROR = "missing script_path"
 
 
 class Py3status:
     """
     """
+
     # available configuration parameters
+    button_show_notification = None
     cache_timeout = 15
-    format = '{output}'
+    format = "{output}"
     localize = True
     script_path = None
     strip_output = False
@@ -62,14 +65,16 @@ class Py3status:
     def external_script(self):
         output_lines = None
         response = {}
-        response['cached_until'] = self.py3.time_in(self.cache_timeout)
+        response["cached_until"] = self.py3.time_in(self.cache_timeout)
         try:
-            output = self.py3.command_output(self.script_path, shell=True, localized=self.localize)
-            output_lines = output.splitlines()
+            self.output = self.py3.command_output(
+                self.script_path, shell=True, localized=self.localize
+            )
+            output_lines = self.output.splitlines()
             if len(output_lines) > 1:
                 output_color = output_lines[1]
-                if re.search(r'^#[0-9a-fA-F]{6}$', output_color):
-                    response['color'] = output_color
+                if re.search(r"^#[0-9a-fA-F]{6}$", output_color):
+                    response["color"] = output_color
         except self.py3.CommandError as e:
             # something went wrong show error to user
             output = e.output or e.error
@@ -94,16 +99,24 @@ class Py3status:
                 except ValueError:
                     pass
         else:
-            output = ''
+            output = ""
 
-        response['full_text'] = self.py3.safe_format(
-            self.format, {'output': output})
+        response["full_text"] = self.py3.safe_format(
+            self.format, {"output": output, "lines": len(output_lines)}
+        )
         return response
 
+    def on_click(self, event):
+        button = event["button"]
+        if button == self.button_show_notification:
+            self.py3.notify_user(self.output)
+            self.py3.prevent_refresh()
+
 
 if __name__ == "__main__":
     """
     Run module in test mode.
     """
     from py3status.module_test import module_test
+
     module_test(Py3status)
