@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Group modules and switch between them.
 
@@ -107,9 +106,9 @@ class Py3status:
     cycle = 0
     fixed_width = False
     format = None
-    format_button_closed = u"+"
-    format_button_open = u"-"
-    format_closed = u"{button}"
+    format_button_closed = "+"
+    format_button_open = "-"
+    format_closed = "{button}"
     open = True
 
     class Meta:
@@ -130,9 +129,9 @@ class Py3status:
         # set default format etc based on click_mode
         if self.format is None:
             if self.click_mode == "button":
-                self.format = u"{output} {button}"
+                self.format = "{output} {button}"
             else:
-                self.format = u"{output}"
+                self.format = "{output}"
         # if no button then force open
         if not self.py3.format_contains(self.format, "button"):
             self.open = True
@@ -147,7 +146,7 @@ class Py3status:
         # ensure that active is valid
         self.active = self.active % len(self.items)
 
-        return set([self.items[self.active]])
+        return {self.items[self.active]}
 
     def _urgent_function(self, module_list):
         """
