@@ -1,12 +1,18 @@
-# -*- coding: utf-8 -*-
 """
 Display number of unread messages from IMAP account.
 
 Configuration parameters:
     allow_urgent: display urgency on unread messages (default False)
+    auth_scope: scope to use with OAuth2 (default 'https://mail.google.com/')
+    auth_token: path to where the pickled access/refresh token will be saved
+        after successful credential authorization.
+        (default '~/.config/py3status/imap_auth_token.pickle')
     cache_timeout: refresh interval for this module (default 60)
+    client_secret: the path to the client secret file with OAuth 2.0
+        credentials (if None then OAuth not used) (default None)
     criterion: status of emails to check for (default 'UNSEEN')
     debug: log warnings (default False)
+    degraded_when_stale: color as degraded when updating failed (default True)
     format: display format for this module (default 'Mail: {unseen}')
     hide_if_zero: hide this module when no new mail (default False)
     mailbox: name of the mailbox to check (default 'INBOX')
@@ -27,16 +33,40 @@ Format placeholders:
 Color options:
     color_new_mail: use color when new mail arrives, default to color_good
 
+OAuth:
+    OAuth2 will be used for authentication instead of a password if the
+    client_secret path is set.
+
+    To create a client_secret for your Google account, visit
+    https://console.developers.google.com/ and create an "OAuth client ID" from
+    the credentials tab.
+
+    This client secret enables the app (in this case, the IMAP py3status module)
+    to request access to a user's email. Therefore the client secret doesn't
+    have to be for the same Google account as the email account being accessed.
+
+    When the IMAP module first tries to access your email account a browser
+    window will open asking for authorization to access your email.
+    After authorization is complete, an access/refresh token will be saved to
+    the path configured in auth_token.
+
+    Requires: Using OAuth requires the google-auth and google-auth-oauthlib
+    libraries to be installed.
+
+    Note: the same client secret file can be used as with the py3status Google
+    Calendar module.
+
 @author obb, girst
 
 SAMPLE OUTPUT
 {'full_text': 'Mail: 36', 'color': '#00FF00'}
 """
 import imaplib
+import os
 from threading import Thread
 from time import sleep
 from ssl import create_default_context
-from socket import error as socket_error
+from socket import setdefaulttimeout, error as socket_error
 
 STRING_UNAVAILABLE = "N/A"
 NO_DATA_YET = -1
@@ -48,9 +78,13 @@ class Py3status:
 
     # available configuration parameters
     allow_urgent = False
+    auth_scope = "https://mail.google.com/"
+    auth_token = "~/.config/py3status/imap_auth_token.pickle"
     cache_timeout = 60
+    client_secret = None
     criterion = "UNSEEN"
     debug = False
+    degraded_when_stale = True
     format = "Mail: {unseen}"
     hide_if_zero = False
     mailbox = "INBOX"
@@ -83,11 +117,16 @@ class Py3status:
         self.mail_count = NO_DATA_YET
         self.connection = None
         self.mail_error = None  # cannot throw self.py3.error from thread
+        self.network_error = None
         self.command_tag = (
             0  # IMAPcommands are tagged, so responses can be matched up to requests
         )
         self.idle_thread = Thread()
 
+        if self.client_secret:
+            self.client_secret = os.path.expanduser(self.client_secret)
+        self.auth_token = os.path.expanduser(self.auth_token)
+
         if self.security not in ["ssl", "starttls"]:
             raise ValueError("Unknown security protocol")
 
@@ -126,6 +165,8 @@ class Py3status:
         elif self.mail_count > 0:
             response["color"] = self.py3.COLOR_NEW_MAIL or self.py3.COLOR_GOOD
             response["urgent"] = self.allow_urgent
+        if self.network_error is not None and self.degraded_when_stale:
+            response["color"] = self.py3.COLOR_DEGRADED
 
         return response
 
@@ -137,11 +178,47 @@ class Py3status:
         if self.use_idle and not supports_idle:
             self.py3.error("Server does not support IDLE")
 
+    def _get_creds(self):
+        from google_auth_oauthlib.flow import InstalledAppFlow
+        from google.auth.transport.requests import Request
+        from google.auth.exceptions import TransportError
+        import pickle
+
+        self.creds = None
+
+        # Open pickle file with access and refresh tokens if it exists
+        if os.path.exists(self.auth_token):
+            with open(self.auth_token, "rb") as token:
+                self.creds = pickle.load(token)
+
+        if not self.creds or not self.creds.valid:
+            try:
+                if self.creds and self.creds.expired and self.creds.refresh_token:
+                    # Credentials expired but contain refresh token
+                    self.creds.refresh(Request())
+                else:
+                    # No valid credentials so open authorisation URL in browser
+                    flow = InstalledAppFlow.from_client_secrets_file(
+                        self.client_secret, [self.auth_scope]
+                    )
+                    self.creds = flow.run_local_server(port=0)
+                # Save the credentials for the next run
+                with open(self.auth_token, "wb") as token:
+                    pickle.dump(self.creds, token)
+            except TransportError as e:
+                # Treat the same as a socket_error
+                raise socket_error(e)
+
     def _connection_ssl(self):
+        if self.client_secret:
+            # Use OAUTH
+            self._get_creds()
+        setdefaulttimeout(self.read_timeout)
         connection = imaplib.IMAP4_SSL(self.server, int(self.port))
         return connection
 
     def _connection_starttls(self):
+        setdefaulttimeout(self.read_timeout)
         connection = imaplib.IMAP4(self.server, int(self.port))
         connection.starttls(create_default_context())
         return connection
@@ -191,8 +268,12 @@ class Py3status:
                 response = socket.read(4096).decode("ascii")
             except socket_error:
                 raise imaplib.IMAP4.abort("Server didn't respond to 'IDLE' in time")
-            if not response.lower().startswith("+ idling"):
-                raise imaplib.IMAP4.abort("While initializing IDLE: " + str(response))
+            # Dovecot will responde with "+ idling", courier will return "+ entering idle mode"
+            # RFC 2177 (https://tools.ietf.org/html/rfc2177) only requires the "+" character.
+            if not response.lower().startswith("+"):
+                raise imaplib.IMAP4.abort(
+                    "While initializing IDLE: {}".format(response)
+                )
 
             # wait for changes (EXISTS, EXPUNGE, etc.):
             socket.settimeout(self.cache_timeout)
@@ -231,12 +312,22 @@ class Py3status:
                 raise imaplib.IMAP4.abort("While terminating IDLE: " + response)
 
     def _get_mail_count(self):
-        try:
-            while True:
+        retry_counter = 0
+        retry_max = 3
+        while True:
+            try:
                 if self.connection is None:
                     self._connect()
                 if self.connection.state == "NONAUTH":
-                    self.connection.login(self.user, self.password)
+                    if self.client_secret:
+                        # Authenticate using OAUTH
+                        auth_string = "user={}\1auth=Bearer {}\1\1".format(
+                            self.user, self.creds.token
+                        )
+                        self.connection.authenticate("XOAUTH2", lambda x: auth_string)
+                    else:
+                        # Login with user and password
+                        self.connection.login(self.user, self.password)
 
                 tmp_mail_count = 0
                 directories = self.mailbox.split(",")
@@ -248,24 +339,59 @@ class Py3status:
                     tmp_mail_count += len(mails)
 
                 self.mail_count = tmp_mail_count
+                self.network_error = None
 
                 if self.use_idle:
                     self.py3.update()
                     self._idle()
+                    retry_counter = 0
                 else:
                     return
-        except (socket_error, imaplib.IMAP4.abort, imaplib.IMAP4.readonly) as e:
-            if self.debug:
-                self.py3.log(
-                    "Recoverable error - " + str(e), level=self.py3.LOG_WARNING
-                )
-            self._disconnect()
-        except (imaplib.IMAP4.error, Exception) as e:
-            self.mail_error = "Fatal error - " + str(e)
-            self._disconnect()
-            self.mail_count = None
-        finally:
-            self.py3.update()  # to propagate mail_error
+            except (socket_error, imaplib.IMAP4.abort, imaplib.IMAP4.readonly) as e:
+                if "didn't respond to 'DONE'" in str(e) or isinstance(e, socket_error):
+                    self.network_error = str(e)
+                    error_type = "Network"
+                else:
+                    error_type = "Recoverable"
+                    # Note: we don't reset network_error, as we want this to persist
+                    # until we either run into a permanent error or successfully receive
+                    # another response from the IMAP server.
+
+                if self.debug:
+                    self.py3.log(
+                        "{} error - {}".format(error_type, e),
+                        level=self.py3.LOG_WARNING,
+                    )
+                self._disconnect()
+
+                retry_counter += 1
+                if retry_counter <= retry_max:
+                    if self.debug:
+                        self.py3.log(
+                            "Retrying ({}/{})".format(retry_counter, retry_max),
+                            level=self.py3.LOG_INFO,
+                        )
+                    continue
+                break
+            except (imaplib.IMAP4.error, Exception) as e:
+                self.mail_error = "Fatal error - {}".format(e)
+                self._disconnect()
+                self.mail_count = None
+
+                retry_counter += 1
+                if retry_counter <= retry_max:
+                    if self.debug:
+                        self.py3.log(
+                            "Will retry after 60 seconds ({}/{})".format(
+                                retry_counter, retry_max
+                            ),
+                            level=self.py3.LOG_INFO,
+                        )
+                    sleep(60)
+                    continue
+                break
+            finally:
+                self.py3.update()  # to propagate mail_error
 
 
 if __name__ == "__main__":
