@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Display song/video and control MPRIS compatible players.
 
@@ -128,6 +127,58 @@ def _get_time_str(microseconds):
     return time
 
 
+class BrokenDBusMpris:
+    class PropertiesChanged:
+        def __init__(self, parent, dbus):
+            self._dbus = dbus
+            self._parent = parent
+
+        def connect(self, callback):
+            def combined_function(*args):
+                callback(*self.filter_messages(*args))
+
+            self._subscription = self._dbus.subscribe(signal_fired=combined_function)
+
+        def disconnect(self):
+            self._subscription.disconnect()
+
+        # For some reason the dbus subscribe filtering doesn't work
+        def filter_messages(self, *args):
+            dbus_params = [
+                "/org/mpris/MediaPlayer2",
+                "org.freedesktop.DBus.Properties",
+                "PropertiesChanged",
+            ]
+
+            for i in range(1, 3):
+                if args[i] != dbus_params[i - 1]:
+                    return ("", {}, [])
+            # The 6th is a tuple, where the actual data is in the 2nd field
+            msg = args[4][1]
+
+            if msg:
+                try:
+                    if "PlaybackStatus" in msg:
+                        self._parent.PlaybackStatus = msg["PlaybackStatus"]
+                    if "Metadata" in msg:
+                        self._parent.Metadata = msg["Metadata"]
+
+                except KeyError:
+                    pass
+            return args[4]
+
+    def __init__(self, dbus, identity, playback_status):
+        self._dbus = dbus
+        self.Identity = identity
+        self.PlaybackStatus = playback_status
+        self.PropertiesChanged = BrokenDBusMpris.PropertiesChanged(self, dbus)
+        self.Metadata = {"xesam:album": None, "xesam:artist": None, "xesam:title": None}
+
+    def get(self, key):
+        data = {"subscription": self.PropertiesChanged._subscription}
+        return data[key]
+
+
 class Py3status:
     """
     """
@@ -139,15 +190,15 @@ class Py3status:
     button_toggle = 1
     format = "[{artist} - ][{title}] {previous} {toggle} {next}"
     format_none = "no player running"
-    icon_next = u"\u25b9"
-    icon_pause = u"\u25eb"
-    icon_play = u"\u25b7"
-    icon_previous = u"\u25c3"
-    icon_stop = u"\u25a1"
+    icon_next = "\u25b9"
+    icon_pause = "\u25eb"
+    icon_play = "\u25b7"
+    icon_previous = "\u25c3"
+    icon_stop = "\u25a1"
     player_priority = []
-    state_pause = u"\u25eb"
-    state_play = u"\u25b7"
-    state_stop = u"\u25a1"
+    state_pause = "\u25eb"
+    state_play = "\u25b7"
+    state_stop = "\u25a1"
 
     def post_config_hook(self):
         if self.py3.is_gevent():
@@ -280,7 +331,8 @@ class Py3status:
             "time": ptime,
             "title": self._data.get("title") or "No Track",
             "nowplaying": self._data.get("nowplaying"),
-            "full_name": self._player_details.get("full_name"),  # for debugging ;p
+            # for debugging ;p
+            "full_name": self._player_details.get("full_name"),
         }
 
         return (placeholders, color, update)
@@ -331,8 +383,8 @@ class Py3status:
     def _set_player(self):
         """
         Sort the current players into priority order and set self._player
-        Players are ordered by working state, then by preference supplied by user
-        and finally by instance if a player has more than one running.
+        Players are ordered by working state, then by preference supplied by
+        user and finally by instance if a player has more than one running.
         """
         players = []
         for name, p in self._mpris_players.items():
@@ -373,12 +425,14 @@ class Py3status:
             if status:
                 player = self._mpris_players[player_id]
 
-                # Note: Workaround. Since all players get noted if playback status
-                #       has been changed we have to check if we are the chosen one
+                # Note: Workaround. Since all players get noted if playback
+                #       status has been changed we have to check if we are the
+                #       chosen one
                 try:
                     dbus_status = player["_dbus_player"].PlaybackStatus
                 except GError:
-                    # Prevent errors when calling methods of deleted dbus objects
+                    # Prevent errors when calling methods of deleted dbus
+                    # objects
                     return
                 if status != dbus_status:
                     # FIXME: WE DON'T RECOGNIZE ANY TITLE CHANGE
@@ -397,17 +451,21 @@ class Py3status:
         if not player_id.startswith(SERVICE_BUS):
             return False
 
+        # Fixes chromium mpris
         try:
             player = self._dbus.get(player_id, SERVICE_BUS_URL)
         except KeyError:
-            return False
+            if "chromium" in player_id:
+                player = BrokenDBusMpris(self._dbus, "Chromium", "Stopped")
+            else:
+                return False
 
         if player.Identity not in self._mpris_names:
             self._mpris_names[player.Identity] = player_id.split(".")[-1]
             for p in self._mpris_players.values():
                 if not p["name"] and p["identity"] in self._mpris_names:
                     p["name"] = self._mpris_names[p["identity"]]
-                    p["full_name"] = u"{} {}".format(p["name"], p["index"])
+                    p["full_name"] = "{} {}".format(p["name"], p["index"])
 
         identity = player.Identity
         name = self._mpris_names.get(identity)
@@ -439,7 +497,7 @@ class Py3status:
             "index": index,
             "identity": identity,
             "name": name,
-            "full_name": u"{} {}".format(name, index),
+            "full_name": "{} {}".format(name, index),
             "status": status,
             "subscription": subscription,
         }
@@ -493,7 +551,7 @@ class Py3status:
                 self._data["title"] = metadata.get("xesam:title")
                 self._data["album"] = metadata.get("xesam:album")
 
-                if metadata.get("xesam:artist") is not None:
+                if metadata.get("xesam:artist"):
                     self._data["artist"] = metadata.get("xesam:artist")[0]
                 else:
                     # we assume here that we playing a video and these types of
@@ -512,7 +570,6 @@ class Py3status:
         if is_stream and self._data.get("title"):
             # delete the file extension
             self._data["title"] = re.sub(r"\....$", "", self._data.get("title"))
-
             self._data["nowplaying"] = metadata.get("vlc:nowplaying")
 
     def kill(self):
@@ -524,6 +581,7 @@ class Py3status:
         """
         if self._kill:
             raise KeyboardInterrupt
+
         current_player_id = self._player_details.get("id")
         cached_until = self.py3.CACHE_FOREVER
 
