@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-"""
+r"""
 Display system RAM, SWAP and CPU utilization.
 
 Configuration parameters:
@@ -41,11 +40,17 @@ Format placeholders:
     {mem_used} used memory
     {mem_used_unit} memory used unit, eg GiB
     {mem_used_percent} used memory percentage
+    {mem_free} free memory
+    {mem_free_unit} free memory unit, eg GiB
+    {mem_free_percent} free memory percentage
     {swap_total} total swap
     {swap_total_unit} swap total memory unit, eg GiB
     {swap_used} used swap
     {swap_used_unit} swap used memory unit, eg GiB
     {swap_used_percent} used swap percentage
+    {swap_free} free swap
+    {swap_free_unit} free swap unit, eg GiB
+    {swap_free_percent} free swap percentage
     {temp_unit} temperature unit
 
 format_cpu placeholders:
@@ -99,7 +104,6 @@ SAMPLE OUTPUT
 ]
 """
 
-from __future__ import division
 from fnmatch import fnmatch
 from os import getloadavg
 
@@ -115,15 +119,15 @@ class Py3status:
     cpu_freq_unit = "GHz"
     cpus = ["cpu?*"]
     format = (
-        "[\?color=cpu_used_percent CPU: {cpu_used_percent}%], "
-        "[\?color=mem_used_percent Mem: {mem_used}/{mem_total} "
+        r"[\?color=cpu_used_percent CPU: {cpu_used_percent}%], "
+        r"[\?color=mem_used_percent Mem: {mem_used}/{mem_total} "
         "{mem_total_unit} ({mem_used_percent}%)]"
     )
-    format_cpu = "\?color=used_percent {used_percent}%"
+    format_cpu = r"\?color=used_percent {used_percent}%"
     format_cpu_separator = " "
     mem_unit = "GiB"
     swap_unit = "GiB"
-    temp_unit = u"°C"
+    temp_unit = "°C"
     thresholds = [(0, "good"), (40, "degraded"), (75, "bad")]
     zone = None
 
@@ -146,9 +150,13 @@ class Py3status:
                 "mem_total": format_vals,
                 "mem_used": format_vals,
                 "mem_used_percent": format_vals,
+                "mem_free": format_vals,
+                "mem_free_percent": format_vals,
                 "swap_total": format_vals,
                 "swap_used": format_vals,
                 "swap_used_percent": format_vals,
+                "swap_free": format_vals,
+                "swap_free_percent": format_vals,
             }
 
         deprecated = {
@@ -196,9 +204,13 @@ class Py3status:
                         "mem_total": ":.2f",
                         "mem_used": ":.2f",
                         "mem_used_percent": ":.2f",
+                        "mem_free": ":.2f",
+                        "mem_free_percent": ":.2f",
                         "swap_total": ":.2f",
                         "swap_used": ":.2f",
                         "swap_used_percent": ":.2f",
+                        "swap_free": ":.2f",
+                        "swap_free_percent": ":.2f",
                     },
                     "format_strings": ["format"],
                 },
@@ -212,10 +224,10 @@ class Py3status:
     def post_config_hook(self):
         self.first_run = True
         temp_unit = self.temp_unit.upper()
-        if temp_unit in ["C", u"°C"]:
-            temp_unit = u"°C"
-        elif temp_unit in ["F", u"°F"]:
-            temp_unit = u"°F"
+        if temp_unit in ["C", "°C"]:
+            temp_unit = "°C"
+        elif temp_unit in ["F", "°F"]:
+            temp_unit = "°F"
         elif not temp_unit == "K":
             temp_unit = "unknown unit"
         self.temp_unit = temp_unit
@@ -262,6 +274,15 @@ class Py3status:
         if self.init["stat"]:
             self.cpus = {"cpus": self.cpus, "last": {}, "list": []}
 
+        if self.init["cpu_temp"]:
+            if self.zone is None:
+                output = self.py3.command_output("sensors")
+
+                for sensor in ["coretemp-isa-0000", "k10temp-pci-00c3"]:
+                    if sensor in output:
+                        self.zone = sensor
+                        break
+
     def _get_cpuinfo(self):
         with open("/proc/cpuinfo") as f:
             return [float(line.split()[-1]) for line in f if "cpu MHz" in line]
@@ -326,21 +347,35 @@ class Py3status:
                     + (meminfo["SReclaimable:"] - meminfo["Shmem:"])
                 )
             )
+            free_mem_kib = total_mem_kib - used_mem_kib
         else:
             total_mem_kib = meminfo["SwapTotal:"]
-            used_mem_kib = total_mem_kib - meminfo["SwapFree:"]
+            free_mem_kib = meminfo["SwapFree:"]
+            used_mem_kib = total_mem_kib - free_mem_kib
 
         if total_mem_kib == 0:
             used_percent = 0
+            free_percent = 100
         else:
             used_percent = 100 * used_mem_kib / total_mem_kib
+            free_percent = 100 - used_percent
 
         unit = "B" if unit == "dynamic" else unit
         (total, total_unit) = self.py3.format_units(total_mem_kib * 1024, unit)
         (used, used_unit) = self.py3.format_units(used_mem_kib * 1024, unit)
-        return total, total_unit, used, used_unit, used_percent
+        (free, free_unit) = self.py3.format_units(free_mem_kib * 1024, unit)
+        return (
+            total,
+            total_unit,
+            used,
+            used_unit,
+            used_percent,
+            free,
+            free_unit,
+            free_percent,
+        )
 
-    def _get_meminfo(self, head=24):
+    def _get_meminfo(self, head=28):
         with open("/proc/meminfo") as f:
             info = [line.split() for line in (next(f) for x in range(head))]
             return {fields[0]: float(fields[1]) for fields in info}
@@ -376,7 +411,7 @@ class Py3status:
                 pass
         if not sensors:
             sensors = self.py3.command_output(command)
-        m = re.search("(Core 0|CPU Temp).+\+(.+).+\(.+", sensors)
+        m = re.search(r"(Core 0|CPU Temp).+\+(.+).+\(.+", sensors)
         if m:
             cpu_temp = float(m.groups()[1].strip()[:-2])
         else:
@@ -390,7 +425,7 @@ class Py3status:
                 with open(zone) as f:
                     cpu_temp = f.readline()
                     cpu_temp = float(cpu_temp) / 1000  # convert from mdegC to degC
-            except (OSError, IOError, ValueError):
+            except (OSError, ValueError):
                 # FileNotFoundError does not exist on Python < 3.3, so we catch OSError instead
                 # ValueError can be thrown if zone was a file that didn't have a float
                 # if zone was not a file, it might be a sensor!
@@ -400,7 +435,7 @@ class Py3status:
             cpu_temp = self._get_cputemp_with_lmsensors()
 
         if cpu_temp is float:
-            if unit == u"°F":
+            if unit == "°F":
                 cpu_temp = cpu_temp * (9.0 / 5.0) + 32
             elif unit == "K":
                 cpu_temp += 273.15
@@ -456,6 +491,9 @@ class Py3status:
                     "mem_used",
                     "mem_used_unit",
                     "mem_used_percent",
+                    "mem_free",
+                    "mem_free_unit",
+                    "mem_free_percent",
                 ]
                 sys.update(zip(mem_keys, mem))
 
@@ -467,6 +505,9 @@ class Py3status:
                     "swap_used",
                     "swap_used_unit",
                     "swap_used_percent",
+                    "swap_free",
+                    "swap_free_unit",
+                    "swap_free_percent",
                 ]
                 sys.update(zip(swap_keys, swap))
 
