@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Control screen rotation.
 
@@ -95,7 +94,7 @@ class Py3status:
         cmd = "xrandr"
         outputs = [self.screen] if self.screen else self._get_active_outputs()
         for output in outputs:
-            cmd += " --output %s --rotate %s" % (output, rotation)
+            cmd += " --output {} --rotate {}".format(output, rotation)
         self.py3.command_run(cmd)
 
     def _switch_selection(self):
