@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 This file is used for the generation of screenshots for py3status
 documentation.
@@ -11,7 +10,6 @@ outside of pythons standard library there are the following requirements:
 PIL may work if installed but is not supported.
 """
 
-from __future__ import division
 
 import ast
 import os
@@ -51,6 +49,10 @@ COLOR_URGENT_BG = "#900000"
 FONT_SIZE = BAR_HEIGHT - (PADDING * 2)
 HEIGHT = TOP_BAR_HEIGHT + BAR_HEIGHT
 
+SAMPLE_DATA_ERROR = dict(
+    color="#990000", background="#FFFF00", full_text=" SAMPLE DATA ERROR "
+)
+
 # font, glyph_data want caching for performance
 font = None
 glyph_data = None
@@ -102,16 +104,11 @@ def contains_bad_glyph(glyph_data, data):
 
     for part in data:
         text = part.get("full_text", "")
-        try:
-            # for python 2
-            text = text.decode("utf8")
-        except AttributeError:
-            pass
 
         for char in text:
             if not check_glyph(ord(char)):
                 # we have not found a character in the font
-                print(u"%s (%s) missing" % (char, ord(char)))
+                print("{} ({}) missing".format(char, ord(char)))
                 return True
     return False
 
@@ -195,35 +192,13 @@ def parse_sample_data(sample_data, module_name):
     {screenshot_name: sample_output}
     """
     samples = {}
-    name = None
-    data = ""
-    count = 0
-    for line in sample_data.splitlines():
-        line = line.strip()
-        if line == "":
-            # blank lines separate screenshots so process the data we have
-            if data:
-                if name:
-                    name = u"%s-%s-%s" % (module_name, count, name)
-                else:
-                    name = module_name
-                try:
-                    output = ast.literal_eval(data)
-                    samples[name] = output
-                except SyntaxError:
-                    samples[name] = {
-                        "color": "#990000",
-                        "background": "#FFFF00",
-                        "full_text": " SAMPLE DATA ERROR ",
-                    }
-                count += 1
-            # clear any data
-            name = None
-            data = ""
-        elif name is None and data == "" and not line[0] in ["[", "{"] and count:
-            name = line
-        else:
-            data += line
+    for index, chunk in enumerate(sample_data.split("\n\n")):
+        chunk = "{}-{}-{}".format(module_name, index, chunk)
+        name, sample = re.split("-?\n", chunk, 1)
+        try:
+            samples[name] = ast.literal_eval(sample)
+        except SyntaxError:
+            samples[name] = SAMPLE_DATA_ERROR
     return samples
 
 
@@ -238,7 +213,7 @@ def get_samples():
         if file.endswith(".py") and file != "__init__.py":
             #  remove .py
             module_name = file[:-3]
-            with open(os.path.join(module_dir, file), "r") as f:
+            with open(os.path.join(module_dir, file)) as f:
                 try:
                     module = ast.parse(f.read())
                 except SyntaxError:
@@ -254,14 +229,12 @@ def get_samples():
     return samples
 
 
-def process(name, data, module=True):
+def process(name, path, data, module=True):
     """
     Process data to create a screenshot which will be saved in
     docs/screenshots/<name>.png
     If module is True the screenshot will include the name and py3status.
     """
-
-    path = "../doc/screenshots"
     # create dir if not exists
     try:
         os.makedirs(path)
@@ -279,7 +252,7 @@ def process(name, data, module=True):
         data = [data]
 
     if contains_bad_glyph(glyph_data, data):
-        print("** %s has characters not in %s **" % (name, font.getname()[0]))
+        print("** {} has characters not in {} **".format(name, font.getname()[0]))
     else:
         create_screenshot(name, data, path, font=font, is_module=module)
 
@@ -290,11 +263,18 @@ def create_screenshots(quiet=False):
     The screenshots directory will have all .png files deleted before new shots
     are created.
     """
+    if os.environ.get("READTHEDOCS") == "True":
+        path = "../doc/screenshots"
+    else:
+        path = os.path.join(
+            os.path.dirname(os.path.dirname(os.path.abspath(__file__))),
+            "doc/screenshots",
+        )
 
     print("Creating screenshots...")
     samples = get_samples()
     for name, data in sorted(samples.items()):
-        process(name, data)
+        process(name, path, data)
 
 
 if __name__ == "__main__":
