@@ -1,10 +1,8 @@
-# -*- coding: utf-8 -*-
 """
 Run formatter tests
 """
 
 import platform
-import sys
 
 from pprint import pformat
 
@@ -17,10 +15,8 @@ from py3status.py3 import NoneColor
 is_pypy = platform.python_implementation() == "PyPy"
 f = Formatter()
 
-python2 = sys.version_info < (3, 0)
-
 param_dict = {
-    "name": u"Björk",
+    "name": "Björk",
     "number": 42,
     "pi": 3.14159265359,
     "yes": True,
@@ -28,9 +24,9 @@ param_dict = {
     "empty": "",
     "None": None,
     "?bad name": "evil",
-    u"☂ Very bad name ": u"☂ extremely evil",
+    "☂ Very bad name ": "☂ extremely evil",
     "long_str": "I am a long string though not too long",
-    "python2_unicode": u"Björk",
+    "python2_unicode": "Björk",
     "python2_str": "Björk",
     "zero": 0,
     "zero_str": "0",
@@ -87,8 +83,6 @@ def attr_getter_fn(attr):
 def run_formatter(test_dict):
     __tracebackhide__ = True
 
-    if test_dict.get("py3only") and python2:
-        return
     if not test_dict.get("pypy", True) and is_pypy:
         return
     if test_dict.get("attr_getter"):
@@ -124,8 +118,6 @@ def run_formatter(test_dict):
         result = result.get_content()
 
     expected = test_dict.get("expected")
-    if python2 and isinstance(expected, str):
-        expected = expected.decode("utf-8")
     if result != expected:
         print("Format\n{}\n".format(test_dict["format"]))
         print("Expected\n{}".format(pformat(expected)))
@@ -154,9 +146,6 @@ def update_placeholders(test_dict):
     result = f.update_placeholders(test_dict["format"], test_dict["updates"])
     expected = test_dict.get("expected")
 
-    if python2 and isinstance(expected, str):
-        expected = expected.decode("utf-8")
-
     if result != expected:
         print("Format\n{}\n".format(test_dict["format"]))
         print("Expected\n{}".format(pformat(expected)))
@@ -180,11 +169,11 @@ def get_color_names(test_dict):
 
 
 def test_1():
-    run_formatter({"format": u"hello ☂", "expected": u"hello ☂"})
+    run_formatter({"format": "hello ☂", "expected": "hello ☂"})
 
 
 def test_2():
-    run_formatter({"format": "hello ☂", "expected": u"hello ☂"})
+    run_formatter({"format": "hello ☂", "expected": "hello ☂"})
 
 
 def test_3():
@@ -377,7 +366,7 @@ def test_39():
 
 def test_40():
     run_formatter(
-        {"format": u"Hello {python2_unicode}! ☂", "expected": "Hello Björk! ☂"}
+        {"format": "Hello {python2_unicode}! ☂", "expected": "Hello Björk! ☂"}
     )
 
 
@@ -386,7 +375,7 @@ def test_41():
 
 
 def test_42():
-    run_formatter({"format": u"Hello {python2_str}! ☂", "expected": "Hello Björk! ☂"})
+    run_formatter({"format": "Hello {python2_str}! ☂", "expected": "Hello Björk! ☂"})
 
 
 def test_43():
@@ -561,7 +550,7 @@ def test_73():
     run_formatter(
         {
             "format": "TEST {simple}",
-            "expected": [{"full_text": u"TEST NY 12:34"}],
+            "expected": [{"full_text": "TEST NY 12:34"}],
             "composite": True,
         }
     )
@@ -595,7 +584,7 @@ def test_77():
     run_formatter(
         {
             "format": "TEST [{simple}]",
-            "expected": [{"full_text": u"TEST NY 12:34"}],
+            "expected": [{"full_text": "TEST NY 12:34"}],
             "composite": True,
         }
     )
@@ -605,7 +594,7 @@ def test_78():
     run_formatter(
         {
             "format": "{simple} TEST [{name}[ {number}]]",
-            "expected": [{"full_text": u"NY 12:34 TEST Björk 42"}],
+            "expected": [{"full_text": "NY 12:34 TEST Björk 42"}],
             "composite": True,
         }
     )
@@ -707,7 +696,7 @@ def test_color_1():
     run_formatter(
         {
             "format": r"[\?color=bad {name}]",
-            "expected": [{"full_text": u"Björk", "color": "#FF0000"}],
+            "expected": [{"full_text": "Björk", "color": "#FF0000"}],
         }
     )
 
@@ -716,7 +705,7 @@ def test_color_1a():
     run_formatter(
         {
             "format": r"\?color=bad {name}",
-            "expected": [{"full_text": u"Björk", "color": "#FF0000"}],
+            "expected": [{"full_text": "Björk", "color": "#FF0000"}],
         }
     )
 
@@ -727,7 +716,7 @@ def test_color_2():
             "format": r"[\?color=good Name [\?color=bad {name}] hello]",
             "expected": [
                 {"full_text": "Name ", "color": "#00FF00"},
-                {"full_text": u"Björk", "color": "#FF0000"},
+                {"full_text": "Björk", "color": "#FF0000"},
                 {"full_text": " hello", "color": "#00FF00"},
             ],
         }
@@ -740,7 +729,7 @@ def test_color_3():
             "format": r"[\?max_length=20&color=good Name [\?color=bad {name}] hello]",
             "expected": [
                 {"full_text": "Name ", "color": "#00FF00"},
-                {"full_text": u"Björk", "color": "#FF0000"},
+                {"full_text": "Björk", "color": "#FF0000"},
                 {"full_text": " hello", "color": "#00FF00"},
             ],
         }
@@ -753,7 +742,7 @@ def test_color_4():
             "format": r"[\?max_length=8&color=good Name [\?color=bad {name}] hello]",
             "expected": [
                 {"full_text": "Name ", "color": "#00FF00"},
-                {"full_text": u"Bjö", "color": "#FF0000"},
+                {"full_text": "Bjö", "color": "#FF0000"},
             ],
         }
     )
@@ -764,8 +753,8 @@ def test_color_5():
         {
             "format": r"[\?color=bad {name}][\?color=good {name}]",
             "expected": [
-                {"full_text": u"Björk", "color": "#FF0000"},
-                {"full_text": u"Björk", "color": "#00FF00"},
+                {"full_text": "Björk", "color": "#FF0000"},
+                {"full_text": "Björk", "color": "#00FF00"},
             ],
         }
     )
@@ -776,8 +765,8 @@ def test_color_6():
         {
             "format": r"[\?color=bad {name}] [\?color=good {name}]",
             "expected": [
-                {"full_text": u"Björk ", "color": "#FF0000"},
-                {"full_text": u"Björk", "color": "#00FF00"},
+                {"full_text": "Björk ", "color": "#FF0000"},
+                {"full_text": "Björk", "color": "#00FF00"},
             ],
         }
     )
@@ -983,14 +972,14 @@ def test_min_length_2():
 
 
 def test_min_length_3():
-    run_formatter({"format": r"[\?min_length=9 [{name}]]", "expected": u"    Björk"})
+    run_formatter({"format": r"[\?min_length=9 [{name}]]", "expected": "    Björk"})
 
 
 def test_min_length_4():
     run_formatter(
         {
             "format": r"[\?min_length=9 [\?color=good {name}]]",
-            "expected": [{"color": "#00FF00", "full_text": u"    Björk"}],
+            "expected": [{"color": "#00FF00", "full_text": "    Björk"}],
         }
     )
 
@@ -1001,7 +990,7 @@ def test_min_length_5():
             "format": r"\?min_length=9 [\?color=bad {number}][\?color=good {name}]",
             "expected": [
                 {"full_text": "  42", "color": "#FF0000"},
-                {"full_text": u"Björk", "color": "#00FF00"},
+                {"full_text": "Björk", "color": "#00FF00"},
             ],
         }
     )
@@ -1013,7 +1002,7 @@ def test_min_length_6():
             "format": r"[\?min_length=9 [\?color=bad {number}][\?color=good {name}]]",
             "expected": [
                 {"full_text": "  42", "color": "#FF0000"},
-                {"full_text": u"Björk", "color": "#00FF00"},
+                {"full_text": "Björk", "color": "#00FF00"},
             ],
         }
     )
@@ -1072,7 +1061,7 @@ def test_not_zero_7():
 
 
 def test_not_zero_8():
-    run_formatter({"format": r"[\?not_zero {name}]", "expected": u"Björk"})
+    run_formatter({"format": r"[\?not_zero {name}]", "expected": "Björk"})
 
 
 def test_not_zero_9():
@@ -1175,7 +1164,7 @@ def test_inherit_color_1():
     run_formatter(
         {
             "format": r"\?color=#F0F [[[{number}]]]",
-            "expected": [{"color": u"#FF00FF", "full_text": u"42"}],
+            "expected": [{"color": "#FF00FF", "full_text": "42"}],
         }
     )
 
@@ -1184,7 +1173,7 @@ def test_inherit_color_2():
     run_formatter(
         {
             "format": r"\?color=#F0F [[\?color=good [{number}]]]",
-            "expected": [{"color": u"#00FF00", "full_text": u"42"}],
+            "expected": [{"color": "#00FF00", "full_text": "42"}],
         }
     )
 
