@@ -33,7 +33,12 @@ OBSOLETE_PARAM = []
 
 RE_PARAM = re.compile(r"^  - `(?P<name>[^`]*)`.*?(\*\(default (?P<value>(.*))\)\*)?$")
 
-AST_LITERAL_TYPES = {"Num": "n", "Str": "s", "NameConstant": "value"}
+AST_LITERAL_TYPES = {
+    "Num": "n",
+    "Str": "s",
+    "NameConstant": "value",
+    "Constant": "value",
+}
 
 MODULE_PATH = os.path.join(
     os.path.dirname(os.path.abspath(__file__)), "..", "py3status", "modules"
@@ -72,12 +77,6 @@ def docstring_params(docstring):
                 if match.group("value"):
                     try:
                         value = eval(match.group("value"))
-                        if isinstance(value, str):
-                            try:
-                                value = value.decode("utf-8")
-                            except AttributeError:
-                                # python3
-                                pass
                         try:
                             value = value.replace("&amp;", "&")
                             value = value.replace("&lt;", "<")
@@ -146,7 +145,7 @@ def get_module_attributes(path):
                     if op == "USub":
                         attr_value = -attr_value
                     else:
-                        attr_value = "UNKNOWN %s UnaryOp %s" % (class_name, op)
+                        attr_value = "UNKNOWN {} UnaryOp {}".format(class_name, op)
                 elif class_name == "BinOp":
                     left = get_value(value.left)
                     right = get_value(value.right)
@@ -157,7 +156,7 @@ def get_module_attributes(path):
                         elif op == "Mult":
                             attr_value = left * right
                         else:
-                            attr_value = "UNKNOWN %s BinOp %s" % (class_name, op)
+                            attr_value = "UNKNOWN {} BinOp {}".format(class_name, op)
                     except Exception:
                         attr_value = "UNKNOWN %s BinOp error" % class_name
                 else:
